import { CollectionConfig } from 'payload/types';

const Dispatches: CollectionConfig = {
  slug: 'dispatches',
  admin: {
    useAsTitle: 'code',
  },
  access: {
    read: () => true,
    create: () => true
  },

  fields: [
    {
      name: 'code',
      type: 'text', 
      required: true,
      maxLength: 20,
      unique: true,
      admin: {
        description: "A unique identifier for the dispatch"
      }
    },
    {
      name: 'products', 
      type: 'relationship', 
      relationTo: 'products', 
      hasMany: true,
      required: true,
    },
    {
      name: 'courier', 
      type: 'relationship', 
      relationTo: 'users',
      hasMany: false,
      required: false
    },
    {
      name: 'maker', 
      type: 'relationship', 
      relationTo: 'makers', 
      hasMany: false,
      required: true
    },
    {
      name: 'retailer', 
      type: 'relationship', 
      relationTo: 'retailers', 
      hasMany: false,
      required: true
    },
    {
      name: 'status',
      type: 'select',
      hasMany: false,
      required: true,
      options: [
        {
          label: 'Requested',
          value: 'requested',
        },
        {
          label: 'Accepted',
          value: 'accepted',
        },
        {
          label: 'Archived',
          value: 'archived',
        },
      ],
    },
    {
      name: 'departure', 
      type: 'date', 
      required: false,
    },
    {
      name: 'arrival', 
      type: 'date', 
      required: false,
    },
    {
      name: 'timeSensitive', 
      type: 'checkbox', 
      required: false,
      defaultValue: false
    },
  ],
};

export default Dispatches;